Struct bolic_network::hub::endpoint::Receiver
source · pub struct Receiver<'a>(/* private fields */);Expand description
Handle for receiving data from an endpoint. It cannot be shared.
Implementations
sourceimpl<'a> Receiver<'a>
impl<'a> Receiver<'a>
sourcepub async fn recv(&mut self, size: Option<usize>) -> Option<Bytes>
pub async fn recv(&mut self, size: Option<usize>) -> Option<Bytes>
Use None as size will retain the messages in the underlying transport and make it
zero-copy. Any other size will rechunk the data in the transport.
pub fn try_recv(&mut self) -> Result<Bytes, ReceiverError>
pub fn drain(&mut self) -> Vec<Bytes>