pub trait GenericSource {
    // Required methods
    fn register(&mut self, notifier: IONotifier) -> Result<(), Error>;
    fn deregister(&mut self) -> Result<(), Error>;
}
Event-loop registration abstraction that could be used by transport implementation in general, especially those which do not fit into mio’s polling system (not a mio::event::Source, not epoll/kqueue supported).

Required Methods

source

fn register(&mut self, notifier: IONotifier) -> Result<(), Error>

source

fn deregister(&mut self) -> Result<(), Error>

Implementors